
              M.A.M.E.  -  Multiple Arcade Machine Emulator
       Copyright (C) 1997, 1998 por Nicola Salmoria y el equipo MAME


Mucha gente ha colaborado en este proyecto, directamente o desarrollando
cdigo fuente usado en la escritura de los controladores. No estamos tratando de
apropiarnos de mritos que no son nuestros. Mira la seccin de reconocimientos 
para ver la lista de contribuyentes, de todas maneras, ten en cuenta que la lista 
est incompleta. Mira tambin la seccin CREDITOS en el emulador para ver la gente 
que ha contribudo a un controlador especfico. De nuevo, la lista estar incompleta.
Sentimos cualquier olvido.

Todas las marcas registradas nombradas en este documento son propiedad de sus 
respectivos dueos.


Uso y Licencia de Distribucin
------------------------------


I. Propsito
------------

   MAME no es estrictamente un proyecto con nimo de lucro. Su principal propsito
   es ser una referencia del trabajo interno de las mquinas arcade emuladas. Est
   hecho con fines educativos y para preservar del olvido en que caeran un montn
   de mquinas histricas cuando el hardware en el que funcionan desapareciese.
   Por supuesto, para preservar los juegos, deber ser capaz de jugar con ellos; 
   puedes ver esto como un efecto secundario agradable.
   No es nuestra intencin infringir copyrights o patentes de los juegos originales.
   Todo el cdigo fuente est disponible gratuitamente. Para funcionar, el emulador
   necesita ROMs de las mquinas arcade originales, que deben ser aportadas por el 
   usuario. No est includo nada del codigo de las roms originales en el ejecutable.

II. Precio
----------
   
   MAME es gratuito. El cdigo fuente tambin. No se permite venderlo.

III. Imgenes ROM 
-----------------
   
   No est permitido distribuir MAME e imgenes de las ROMs en el mismo soporte fsico.
   PUEDES ponerlas en tu pgina web pero slo si avisas a los usuarios del estado
   del copyright de las ROMs y de los aspectos legales correspondientes. NO est
   permitido poner el MAME en tu pgina web en un archivo junto a todas las ROMs 
   soportadas o junto a ficheros con ms de un conjunto de ROMs.
   No est permitido distribuir MAME de cualquier manera si vendes o anuncias 
   cd-roms ilegales o cualquier otro soporte fsico incluyendo imgenes de las ROMs.
   La restriccin se aplica incluso si no sacas dinero directamente con ello.
   La restriccin, desde luego, no se aplica si los cd-roms son publicados por los
   dueos de los copyrights de ls ROMs.	 

IV. Integridad de la Distribucin
---------------------------------

   Mame debe ser distribudo slo dentro del archivo original. No debes distribuir
   una versin modificada, ni quitar ni aadir ficheros al archivo. Aadir un fichero
   de texto para anunciar tu pgina web slo se permite si tu pgina contribuye
   con material original a la escena de la emulacin.

V. Distribucin del Cdigo Fuente
---------------------------------

   Si distribuyes  el ejecutable, deberas distribuir el fuente. Si no puedes, debes
   poner un enlace a un sitio donde se pueda conseguir el fuente.

VI. Reutilizacin del Cdigo Fuente
-----------------------------------
   
   Este captulo no debera aplicarse a partes especficas de MAME 
   (p.e. emuladores de CPU), las cuales tienen diferentes notas de coprright.
   El cdigo fuente no se puede usar en un producto comercial sin autorizacin
   escrita de los autores. Su uso en productos no comerciales est permitido e 
   incluso se anima a ello; de todos modos, si usas partes del cdigo fuente de
   MAME, debes hacer accesible gratuitamente todo el cdigo fuente.
   Trabajos derivados tambin son permitidos, pero no se anima a ello: MAME es un 
   proyecto que evoluciona continuamente y deberas, en beneficio tuyo, mandar tus
   contribuciones al equipo de desarrollo, para que puedan ser integradas en la
   distribucin principal. El uso de la informacin contenida en el cdigo fuente
   es gratuito. De todas maneras, dada la cantidad de tiempo y energa que llev
   recopilar la informacin, apreciaramos que la informacin adicional que 
   pudieras tener, fuera gratuita tambin. 
   


Cmo contactar con nosotros
---------------------------

La pgina oficial del MAME es http://mame.retrogames.com/. Siempre podras encontrar
la ultima versin alli, incluidas las betas, e informacin sobre como va el desarrollo
del MAME.

Estas son algunas de las personas que contribuyen con el MAME. Si tienes comentarios,
sugerecias o informacin de fallos en algun driver, mira los creditos del driver
en cuestion para ver quien ha trabajado en ese driver y mandaselos a el. Si no estas
seguro de a quien escribir, escribe a Nicola. Si tienes comentarios especificos sobre
otra version que no sea la de DOS (ej. Mac, Win32, Unix), estas deberan ser mandadas
al que mantenga esa version (mira la documentacin para ver quien es). NO MANDES ESTO
A NICOLA - sera ignorado.

Nicola Salmoria    MC6489@mclink.it

Mike Balfour       mab22@po.cwru.edu
Aaron Giles        agiles@sirius.com
Chris Moore        chris.moore@writeme.com
Brad Oliver        bradman@primenet.com
Andrew Scott       ascott@utkux.utcc.utk.edu
Zsolt Vasvari      vaszs01@banet.net

NO MANDES ARCHIVOS BINARIOS SI CONSULTAR PREVIAMENTE, *ESPECIALMENTE* ROMS.

Estas no son direcciones de soporte. Preguntas de soporte mandadas aqu sern
ignoradas. Por favor, entiende que es un proyecto gratuito, mayormente indicado
para usuarios expertos. No tenemos medios para dar soporte al usuario final.
Bsicamente, si no puedes hacer funcionar el emulador, haz lo siguiente:
Primero lee los documentos. Si no encuentras la respuesta, prueba mirando las 
secciones de principiantes de pginas de emuladores o pregunta en algn canal 
del IRC (p.e. #emuladores) o en los tableros de mensajes de emulacin 
http://www.macmame.org/wwwboard/mame/.

Para encontrar informacin acercade como compilar el MAME, mira estas paginas:
http://zan.emuunlim.com/mame/compile/compilemame.html
http://zan.emuunlim.com/mame/compile/compilemamebeta.html

NO MANDES PETICIONES DE NUEVOS JUEGOS PARA AADIR.
POr favor, no nos mandes informacion qeu hayas encontrado en internet - somos
suficientemente capaces de encontrarla por nosotros mismos, gracias.


Reconocimientos
---------------

Lo primero, gracias a Allard van der Bas (avdbas@wi.leidenuniv.nl) por su 
Recopilatorio de Programacin de Emulacin Arcade en
http://valhalla.ph.tn.tudelft.nl/emul8
Sin l, nunca habra intentado escribir un emulador.
Desafortunadamente, el original est cerrado, pero su espritu contina en 
MAME


Z80 emulator Copyright (c) 1998 Juergen Buchmueller, all rights reserved.
M6502 emulator Copyright (c) 1998 Juergen Buchmueller, all rights reserved.
I86 emulator by David Hedley, modified by Fabrice Frances (frances@ensica.fr)
M6809 emulator by John Butler, based on L.C. Benschop's 6809 Simulator V09.
M6808 based on L.C. Benschop's 6809 Simulator V09.
80x86 asm M6808 emulator Copyright 1998, Neil Bradley, All rights reserved
M68000 emulator Copyright 1999 Karl Stenerud.  All rights reserved.
80x86 M68000 emulator Copyright 1998, Mike Coates, Darren Olafson.
8039 emulator by Mirko Buffoni, based on 8048 emulator by Dan Boris.
T-11 emulator Copyright (C) Aaron Giles 1998
TMS34010 emulator by Alex Pasadyn and Zsolt Vasvari.
TMS9900 emulator by Andy Jones, based on original code by Ton Brouwer.

TMS5220 emulator by Frank Palazzolo.
AY-3-8910 emulation based on various code snippets by Ville Hallik,
  Michael Cuddy, Tatsuyuki Satoh, Fabrice Frances, Nicola Salmoria.
YM-2203 and YM-2151 emulation by Tatsuyuki Satoh.
POKEY emulator by Ron Fries (rfries@aol.com).
Many thanks to Eric Smith, Hedley Rainnie and Sean Trowbridge for information
   on the Pokey random number generator.
NES sound hardware info by Jeremy Chadwick and Hedley Rainne.
YM3812 and YM3526 emulation by Carl-Henrik Skrstedt.
YM2610 emulation by Hiromitsu Shioya.

Background art by Peter Hirschberg (PeterH@cronuscom.com).

Allegro library by Shawn Hargreaves, 1994/97
SEAL Synthetic Audio Library API Interface Copyright (C) 1995, 1996
   Carlos Hasan. All Rights Reserved.
Video modes created using Tweak 1.6b by Robert Schmidt, who also wrote
   TwkUser.c.
"inflate" code for zip file support by Mark Adler.

Big thanks to Gary Walton (garyw@excels-w.demon.co.uk) for too many things
   to mention them all.

Modo de uso
-----------

MAME [nombre del juego a ejecutar] [opciones]

por ejemplo:

MAME mspacman -soundcard 0    cargara el Ms. PacMan sin sonido


opciones:
-scanlines/-noscanlines (por defecto: -scanlines)
              si el modo por defecto no funciona con tu monitor/tarjeta de 
              video (doble imagen/imagen parpadeante), usa -noscanlines o
	      -vesa.
-vesa/-novesa (por defecto: -novesa)
              Decide si usar el modo VGA entrelazado o modo VESA estndar.
              Ten en cuenta que algunos juegos requieren modo VESA, siendo
		  -novesa ignorado en esos juegos.
-ntsc         un modo 288x224 con frecuencias NTSC estndar. Necesitas
              hardware adicional (convertidor VGA a TV) para poder usarlo.
-vesa1        ya no existe. usa -vesa
-vesa2b       ya no existe. usa -vesa
-vesa2l       ya no existe. usa -vesa
-vesamode vesa1/vesa2b/vesa2l/vesa3
              Junto con la opcion "-vesa", selecciona los modo VESA a probar.
              Por defecto es vesa2l.
-resolution XxY
              donde X e Y son anchura y altura (ej: '-resolution 800x600')
		  Mame elige sus resoluciones. T puedes sobreescribirlo con esta
		  opcin.
		  Puedes usar -XxY (ej: -800x600) como atajo. A los autores de 
		  lanzadores se les recomienda usar -resolution XxY.
-320          ya no existe. Usa -320x240.
              Si te sale un error '320x240 not supported', probablemente
              necesites Scitech's Display Doctor, que te proporciona
              implementacin estndar VESA "de hecho"
		  (http://www.scitechsoft.com)
		  Nota: es una buena alternativa a '-640x480 -noscanlines'
-400          lo mismo, usa -400x300
-512          lo mismo, usa -512x384
-640          lo mismo, usa -640x480
-800          lo mismo, usa -800x600.
-1024         lo mismo, usa -1024x768
-skiplines N  dado que muchos juegos usan una pantallas ms grandes que 240
	      lneas, no entran en la pantalla. El parmetro "N" proporciona
	      el nmero inicial de lneas para evitar en la parte de arriba
	      de la pantalla. Puedes ajustar la posicin durante el juego 
	      con las teclas PGUP y PGDN.
-skipcolumns N igual pero mueve la pantalla horizontalmente. Esto es extrao, ya
	      que la pantalla se ajusta a la pantalla. Para ello, SHIFT +
	      PGUP/PGDN.
-double/-nodouble (por defecto: auto)
              usa nodouble para desactivar doblaje de pixels en el modo VESA 
	      (ms rpido, pero ms pequeo). Usa double cuando la imagen no se 
	      ajuste a la pantalla (usa PGUP y PGDN para scrollear).
	      usa nodouble para desactivar doblaje de pixel en modo VESA
-depth n      (por defecto: 16)
              Algunos juegos necesitan modos de 65k colores para conseguir 
	      grficos apropiados. Para mejorar la velocidad usag -depth 8,
	      que pone a modo 256 colores.
-gamma n      (por defecto: 1.2)
              Establece el factor de correccion de gama inicial.
-vgafreq n    donde n puede ser 0 (por defecto) 1, 2 o 3. Usa diferentes
	      frecuencias para el modo customizado de video. Puede reducir 
	      el parpadeo, especialmente en 224x288 modo noscanlines.
              AVISO: LAS FRECUENCIAS USADAS PUEDEN ESTROPEAR EL MONITOR.
-vsync/-novsync (por defecto: -novsync)
              sincroniza video display con el video beam en vez de usar el
              reloj. Esta opcin slo se puede usar si el modo de video elegido
		  tiene una apropiada frecuencia de refresco.
		  Si ests usando modo tweaked?, MAME tratar de elegir el valor
		  correcto de -vgafreq; lo puedes machacar de todas maneras.
		  Nota: el modo 224x288 noscanlines no funciona en la mayora de las
		  tarjetas. Este modo se usa en muchos juegos, p.e.Pac Man y Galaga.
		  Si la tarjeta no funciona, usa la versin scanlines o no uses
		  -vsync. Si usas un modo VESA, deberas usar el programa que viene 
		  con tu tarjeta de video, para poner la apropiada frecuencias de 
		  refresco. Cuando esta opcin est activada, la velocidad no bajar
		  si tu sistema no es muy rpido.

-alwayssynced/-noalwayssynced (por defecto: -noalwayssynced)
              
-ror          rotar la pantalla 90 en el sentido horario.
-rol          rotar la pantalla 90 en el sentido antihorario.
-flipx        girar la pantalla horizontalmente.
-flipy        girar la pantalla verticalmente.
              -ror y -rol dan scanlines *vertical* autntico.
              PELIGRO:
              Un monitor es un complicado, aparato electrnico de alto voltaje.
	      Hay monitores creados para ser girados. Si el tuyo no lo es, t
	      sabrs lo que haces

-norotate     Desactiva todas las rotaciones internas de la imagen. Hay
              controladores que no usan rotacin centralizada del MAME, por eso
	      -norotate no tiene efecto. Si da problemas, usa
              -norotate -flipx -flipy.

-soundcard n  elige la tarjeta de sonido (si no, te lo preguntar)
-sr n         wl valor por defecto es 22050. Valores ms pequeos (11025)
              causarn menor calidad de sonido pero mayor velocidad de emulacin.
	      Y viceversa (44100).
-sb n         coloca los bits de samples ed sonido, 8 o 16. Por defecto, 8.
              16 aumentar la calidad en ciertos juegos, pero reducir la 
	      velocidad. Esto es por software. La tarjeta de sonido siempre se
	      usar en modo 16 bits, si es posible.
-stereo/-nostereo (por defecto: -stereo)
              activa la salida estereo en los juegos que lo soporten.
-joy n (por defecto: none) permite jugar con joystick, n puede ser:
              0/none       - sin joystick
              1/standard   - joystick normal de 2 botones
              2/dual       - joystick dual (como el mio ;D)
              3/button4    - Stick/Pad con 4 botones
              4/button6    - Stick/Pad con 6 botones
              5/button8    - Stick/Pad con 8 botones
              6/fspro      - CH Flightstick Pro
              7/wingex     - Wingman Extreme
                           - Wingman Warrior sin spinner
              8/sidewinder - Microsoft Sidewinder (up to 4)
              9/gamepadpro - Gravis GamePad Pro
              sneslpt1     - SNES pad en LPT1 (necesita hardware especial)
              sneslpt2     - SNES pad en LPT2 (necesita hardware especial)
              sneslpt3     - SNES pad en LPT3 (necesita hardware especial)

              Notas:
              1) Utilize el menu TAB para calibrar los joysticks analogicos. Los datos
              de la calibracion se guardaran en el mame.cfg. Si estas utilizando joysticks
              diferentes para cada juego, deberas calibrar el joystick cada vez :(
              2) La descripcion del Joystick mediante numero dejara de ser soportada en
              futuras versiones del MAME. Utilize el nombre simbolico.
              3) Los botones extra de los joysticks no nombrados no funcionaran.
	      4) El site "oficial" de soporte del Snespad es http://snespad.emulationworld.com

-ym3812opl/-noym3812opl (por defecto: -ym3812opl) utilizael chip OPl de la SoundBlaster
              para la emulacion del chip YM3812. Esto es mas rapido, y es casi igual ya que 
              estos dos chips son 100% compatibles. Sin embargo, el pitch puede ser incorrecto.
	      Hagase notar que con la opcion -no3812opl necesitaras samples externos.
-log          crea un registro con los accesos ilegales a memoria en ERROR.LOG
-help, -?     muestra la version del MAME y la informacion del copyright
-list         muestra una lista de los juegos soportados
-listfull     muestra una lista con los nombres de los directorios + descripciones
-listroms     muestra las roms requeridas por el juego seleccionado
-listsamples  muestra los samples requeridos por el juego seleccionado
-listdetails  muestra una lista detallada de los drivers y el hardware que usan
-listgames    lista los juegos soportados, ao, fabricante
-listinfo     lista de forma comprensiva los detalles de todos los juegos soportados
-listclones   lista todos los clones de un juego indicado
-verifyroms   chequea el juego seleccionado buscando roms perdidas o invalidas
-verifysamples chequea el juego seleccionado en busca de samples
-romdir       especifica un directorio alterno para cargar las ROMs del juego especificado
-mouse/-nomouse (por defecto: -mouse) activa/desactiva el soporte de raton
-frameskip n (por defecto: auto)
              salta frames para acelerar la emulacion. El argumento es el numero de cuadros 
              a saltar de 12/60. Por ejemplo, si el juego normalmente funciona a 60fps,
              "-frameskip 2" lo ejecutara a  50 fps, y "-frameskip 6" a 30 fps. 
	      Use F11 para comprobar la velocidad que alcanza tu oredenador.
              Si esta es menor del 100%, incrementa el valor del frameskip.
	      Presiona F9 durante el juego para variar el valor del frameskip.
	      Cuando el frameskip esta en auto(por defecto), el frameskip se ajusta
              dinamicamente para mostrar el mayor n de cuadros por segundo manteniendo
	      la velocidad al 100%
-antialias/-noantialias (por defecto: -antialias)
              activa el antialiasing en los juegos vectoriales
-beam n       ajusta el tamao en pixels de los vectores. n es en punto en el rango
              del 1.00 al 16.00.
-flicker n    make the vectors flicker. n is an optional argument, a float in
              the range 0.00 - 100.00 (0=none 100=maximum).
-translucency/-notranslucency (por defecto: -translucency)
              activa o desactiva las transparencias en los vectores.
-cheat        trucos como la supervelocidad en el Pac Man o el salto de nivel en otros 
	      juegos estan desabilitados por defecto. Utiliza esta opcion para habilitar
	      estos trucos.
-debug        ACTIVA EL DEBUGGER INTEGRADO. Durante la emulacion, presiona la tilde
              para entrar al debugger. Esto solo esta disponible si el mame a sido
	      compilado con la opcion MAME_DEBUG activada.
-profiler     Activa el profiler. Presione Shift+F11 para verlo en pantalla.
-record name   graba los movimientos del joystick en un archivo INP/nombre.inp.
-playback name reproduce los movimientos del joystick desde un archivo INP/nombre.inp.
-savecfg      no esta soportado por el momento
-ignorecfg    ignora el archivo mame.cfg y comienza con las opciones por defecto

TECLAS
------
Tab          Cambia al menu de configuracion
Tilde        cambia al menu en pantalla
P            Pausa
F3           Resetear
F4           Muestra los graficos del juego. Utilize los cursores para cambiar set/color,
             F4 o Esc para volver a la emulacion.
F9           Cambia el frameskip al momento
F10          Cambia la velocidad del motor grafico
F11          Muestra la velocidad en el monitor
F12          Graba una captura de pantalla. El directorio por defecto es el PCX, tienes que 
	     crearlo tu, ya que el MAME no lo crea por defecto.
ESC          Salir del Emulador